@@ -1,12 +1,13 @@
 from __future__ import absolute_import
 from __future__ import unicode_literals
-
+import os
 from laipvt.interface.middlewareinterface import MiddlewareInterface
 from laipvt.handler.middlewarehandler import NginxConfigHandler
 from laipvt.handler.confighandler import CheckResultHandler
 from laipvt.sysutil.template import FileTemplate
 from laipvt.sysutil.util import path_join, log, status_me, ssh_obj
 from laipvt.model.cmd import ComposeModel
+from laipvt.sysutil.gvalue import CERTS_PATH
 
 
 
@@ -23,8 +24,21 @@ class NginxController(MiddlewareInterface):
         self.apiserver_cluster_conf_template = path_join(self.template, "tcp/apiserver_cluster.conf")
         self.nginx_cfg = NginxConfigHandler().get_config_with_check_result()
         self.nginx_cfg["nginx"]["ipaddress"] = self.handler.cfg["ipaddress"]
+        self.nginx_cfg.update(self.check_result.__dict__)
+        # if self.nginx_cfg["config"]["deploy_https"]:
+        #     if self.nginx_cfg["config"]["self_signed_ca"]:
+        #         self.nginx_cfg["config"]["cert_path"] = os.path.dirname(SERVER_SECURE_KEY)
+        #     else:
+        #         self.nginx_cfg["config"]["cert_path"] = os.path.dirname(self.nginx_cfg["config"]["ca_key_path"])
 
     def _generic_config(self):
+        if self.nginx_cfg["config"]["deploy_https"]:
+            if self.nginx_cfg["config"]["self_signed_ca"]:
+                self.nginx_cfg["config"]["cert_path"] = CERTS_PATH
+                self._send_https_ca_file()
+            else:
+                self.nginx_cfg["config"]["cert_path"] = os.path.dirname(self.nginx_cfg["config"]["ca_key_path"])
+
         log.info("渲染nginx配置文件")
         for num_id in range(len(self.all_server)):
             FileTemplate(self.nginx_cfg, self.nginx_conf_template, self.nginx_conf_tmp).fill()
@@ -45,6 +59,19 @@ class NginxController(MiddlewareInterface):
             finally:
                 ssh_cli.close()
 
+    def _send_https_ca_file(self):
+        for server in self.all_server:
+            log.info("分发%s https证书文件至 %s" % (self.middleware_name, server.ipaddress))
+            ssh_cli = ssh_obj(ip=server.ipaddress, user=server.username, password=server.password, port=server.port)
+            try:
+                ssh_cli.put("/tmp/certs", CERTS_PATH)
+
+            except Exception as e:
+                log.error(e)
+                exit(2)
+            finally:
+                ssh_cli.close()
+
     def renew_apiserver_config(self):
         log.info("将k8s master节点渲染到apiserver配置文件中")
         for num_id in range(len(self.all_server)):
@@ -102,4 +129,3 @@ class NginxController(MiddlewareInterface):
         self._send_docker_compose_file()
         self._start()
         self._check()
-
