@@ -76,6 +76,15 @@ class CommanderController(ServiceInterface):
                         config_server = "{}:{}".format(self.middleware_cfg["redis"]["ipaddress"][0],
                                                        self.middleware_cfg["redis"]["port"])
 
+                    if self.middleware_cfg["config"]["deploy_https"]:
+                        oidc_authority="https://{}:{}".format(
+                            self.middleware_cfg["identity"]["lb"],
+                            self.middleware_cfg["identity"]["nginx_proxy_port"])
+                    else:
+                        oidc_authority="http://{}:{}".format(
+                            self.middleware_cfg["identity"]["lb"],
+                            self.middleware_cfg["identity"]["nginx_proxy_port"])
+
                     cmd = HELM_INSTALL_COMMANDER.format(
                         process=process, replicas=self.replicas,
                         registry_hub=path_join(self.registry_hub, project),
@@ -88,7 +97,7 @@ class CommanderController(ServiceInterface):
                         mysql_password=self.middleware_cfg["mysql"]["password"],
                         etcd_endpoint=self.etcd_endpoint, mysql_database="uibot_global",
                         mysql_charset="utf8mb4",
-                        oidc_authority="http://{}:{}".format(self.middleware_cfg["identity"]["lb"], self.middleware_cfg["identity"]["nginx_proxy_port"]),
+                        oidc_authority=oidc_authority,
                         oidc_secret="laiye",
                         file_path=file_path)
 
@@ -99,7 +108,7 @@ class CommanderController(ServiceInterface):
             for process in processes:
                 log.info("{}开始更新".format(process))
                 self._create_logs_dir(service)
-                file_path = os.path.join(self.service_path, "charts", process)
+                file_path = os.path.join(self.service_path.charts, process)
 
                 if self.middleware_cfg["redis"]["is_deploy"]:
                     config_server = "\,".join(
@@ -189,10 +198,14 @@ class CommanderController(ServiceInterface):
     def login_tenant(self):
         log.info("登录租户管理平台")
         data = {'userName': 'admin', 'password': '123456'}
-        login_url = "http://{host}:{port}/api/global/account/webLogin".format(
-            host=self.middleware_cfg.nginx.lb, port=self.middleware_cfg.nginx.commander_tenant_port
+        if self.middleware_cfg["config"]["deploy_https"]:
+            protocol="https"
+        else:
+            protocol="http"
+        login_url = "{protocol}://{host}:{port}/api/global/account/webLogin".format(
+            protocol=protocol, host=self.middleware_cfg.nginx.lb, port=self.middleware_cfg.nginx.commander_tenant_port
         )
-        response = requests.post(login_url, json=data)
+        response = requests.post(login_url, json=data, verify=False)
         auth_cookie = ''
         # print(response)
         ret = response.json()
@@ -218,10 +231,14 @@ class CommanderController(ServiceInterface):
             "password": self.middleware_cfg.mysql.password,
             "type": "10"
         }
-        mysql_url = "http://{host}:{port}/api/global/database/create".format(
-            host=self.middleware_cfg.nginx.lb, port=self.middleware_cfg.nginx.commander_tenant_port
+        if self.middleware_cfg["config"]["deploy_https"]:
+            protocol="https"
+        else:
+            protocol="http"
+        mysql_url = "{protocol}://{host}:{port}/api/global/database/create".format(
+            protocol=protocol, host=self.middleware_cfg.nginx.lb, port=self.middleware_cfg.nginx.commander_tenant_port
         )
-        resp1 = requests.post(mysql_url, json=db_mysql, cookies=auth_cookie)
+        resp1 = requests.post(mysql_url, json=db_mysql, cookies=auth_cookie, verify=False)
         json_resp1 = resp1.json()
         if json_resp1['code'] == 0:
             log.info("配置MySQL数据库完成")
