@@ -11,8 +11,7 @@ from laipvt.model.cmd import ComposeModel
 from laipvt.sysutil.util import path_join, ssh_obj,log
 from laipvt.sysutil.gvalue import CHECK_INTERVAL
 from laipvt.sysutil.template import FileTemplate
-from laipvt.sysutil.command import RM
-
+from laipvt.sysutil.command import RM, MKDIR_DIR, CHMOD_777
 
 class MiddlewareInterface():
     def __init__(self, result: CheckResultHandler, handler: MiddlewareConfigHandler, template: str):
@@ -79,11 +78,11 @@ class MiddlewareInterface():
         finally:
             ssh_cli.close()
 
-    def send_config_file(self, server, src, dest):
+    def send_config_file(self, server, src, dest, ignore=''):
         log.info("分发配置文件{} 到 {}:{}".format(src, server.ipaddress, dest))
         ssh_cli = ssh_obj(ip=server.ipaddress, user=server.username, password=server.password, port=server.port)
         try:
-            ssh_cli.put(src, dest)
+            ssh_cli.put(src, dest, ignore)
         except Exception as e:
             log.error(e)
             exit(2)
@@ -153,6 +152,17 @@ class MiddlewareInterface():
             finally:
                 ssh_cli.close()
 
+    def create_logs_dir(self, log_path):
+        log.info("创建服务日志目录及授权:{}".format(log_path))
+        cmd = [
+            MKDIR_DIR.format(log_path),
+            CHMOD_777.format(log_path)
+        ]
+        for server in self.master_server:
+            ssh_cli = ssh_obj(ip=server.ipaddress, user=server.username,
+                              password=server.password, port=server.port)
+            ssh_cli.run_cmdlist(cmd)
+
     def check(self) -> bool:
         pass
 
