@@ -32,6 +32,7 @@ class ServiceInterface:
         for k, v in self.middleware_cfg.items():
             if not self.middleware_cfg[k]["ipaddress"]:
                 self.middleware_cfg[k]["ipaddress"] = self.middleware_server_list
+        self.middleware_cfg.update(self.check_result.__dict__)
 
         self.servers = check_result.servers.get()
         self.service_info = service_path.config
@@ -44,10 +45,10 @@ class ServiceInterface:
         self.service_charts_remote = path_join(self.deploy_dir, "charts")
         self.harbor_cfg = HarborConfigHandler().get_config_with_check_result()
         try:
-            harbor_ip = self.harbor_cfg["harbor"]["ipaddress"][0]
+            harbor_ip = self.harbor_cfg["harbor"]["lb"]
         except IndexError:
             harbor_ip = self.check_result.servers.get_role_ip("harbor")[0]
-        self.registry_hub = "{}:{}".format(harbor_ip, self.harbor_cfg["harbor"]["http_port"])
+        self.registry_hub = "{}:{}".format(harbor_ip, self.harbor_cfg["harbor"]["nginx_harbor_proxy_port"])
 
         self.etcd_servers = self.check_result.servers.get_role_ip("master")
         self.etcd_endpoint = "\,".join(
@@ -67,7 +68,7 @@ class ServiceInterface:
 
         self.replicas = 1
         self.nodes = self.check_result.servers.get_role_obj("node")
-        self.master_host = self.check_result.servers.get_role_ip("master")[0]
+        self.master_host = self.check_result.servers.get_role_obj("master")[0]
         self.harbor_hosts = self.check_result.servers.get_role_obj("harbor")
 
         self.rabbitmq_init_file_template_path = path_join(self.templates_dir, "init_rabbitmq.tmpl")
@@ -136,11 +137,11 @@ class ServiceInterface:
             for ns in namespaces:
                 log.info("创建namespace: {}".format(ns))
                 cmd = CREATE_NS.format(ns)
-                self._exec_command_to_host(cmd=cmd, server=self.harbor_hosts[0], check_res=False)
+                self._exec_command_to_host(cmd=cmd, server=self.master_host, check_res=False)
         if istio_injection_namespaces:
             for ns in istio_injection_namespaces:
                 inject_cmd = ISTIO_INJECTION_NS.format(ns)
-                self._exec_command_to_host(cmd=inject_cmd, server=self.harbor_hosts[0], check_res=False)
+                self._exec_command_to_host(cmd=inject_cmd, server=self.master_host, check_res=False)
 
     def deploy_istio(self):
         # 渲染istio配置
@@ -151,7 +152,7 @@ class ServiceInterface:
         ).fill()
         self._send_file(src=self.env_k8s_config_dest, dest=self.env_k8s_config_remote)
         cmd = KUBECTL_APPLY.format(path_join(self.env_k8s_config_remote, "istio"))
-        self._exec_command_to_host(cmd=cmd, server=self.harbor_hosts[0])
+        self._exec_command_to_host(cmd=cmd, server=self.master_host)
 
     def _create_logs_dir(self, project):
         log_path = os.path.join(self.deploy_dir, "Logs", project)
@@ -172,7 +173,7 @@ class ServiceInterface:
                 check_cmd = HELM_LIST.format(
                     process, process
                 )
-                check_results = self._exec_command_to_host(cmd=check_cmd, server=self.harbor_hosts[0], check_res=False)
+                check_results = self._exec_command_to_host(cmd=check_cmd, server=self.master_host, check_res=False)
                 if check_results["code"] == 0:
                     log.warning("{} helm部署记录中已经存在，不做更新，如需要更新，可以先行删除".format(process))
 
@@ -188,14 +189,14 @@ class ServiceInterface:
                         etcd_endpoint=self.etcd_endpoint,
                         file_path=file_path)
 
-                    self._exec_command_to_host(cmd=cmd, server=self.harbor_hosts[0])
+                    self._exec_command_to_host(cmd=cmd, server=self.master_host)
 
     def upgrade_service(self, project):
         for service, processes in self.service_path.config.services.items():
             for process in processes:
                 log.info("{}开始部署".format(process))
                 self._create_logs_dir(service)
-                file_path = os.path.join(self.service_charts_remote, process)
+                file_path = os.path.join(self.service_path.charts, process)
                 # print(file_path)
                 cmd = HELM_UPGRADE_INSTALL.format(
                     process=process, replicas=self.replicas,
@@ -204,7 +205,7 @@ class ServiceInterface:
                     pvt_work_dir=self.deploy_dir,
                     etcd_endpoint=self.etcd_endpoint,
                     file_path=file_path)
-                self._exec_command_to_host(cmd=cmd, server=self.harbor_hosts[0])
+                self._exec_command_to_host(cmd=cmd, server=self.master_host)
 
     def proxy_on_nginx(self, nginx_template, nginx_tmp, nginx_file_remote):
         log.info("渲染nginx代理配置文件: {} -- > {}".format(nginx_template, nginx_tmp))
@@ -288,14 +289,14 @@ class ServiceInterface:
         check_cmd = HELM_LIST.format(
             module_name, module_name
         )
-        check_results = self._exec_command_to_host(cmd=check_cmd, server=self.harbor_hosts[0], check_res=False)
+        check_results = self._exec_command_to_host(cmd=check_cmd, server=self.master_host, check_res=False)
         if check_results["code"] == 0:
             log.warning("{} helm部署记录中已经存在，不做更新，如需要更新，可以先行删除".format(module_name))
 
         else:
             file_path = os.path.join(self.service_charts_remote, module_name)
             # print(file_path)
-            tag = "v2.2.0-crypt-nolm" if self.service_path.config.machine_type == "cpu" else "v2.2.0-crypt-nolm-gpu"
+            tag = "2.4.0-cpu" if self.service_path.config.machine_type == "cpu" else "2.4.0-gpu"
             cmd = HELM_INSTALL_TF_SERVICE.format(
                 process=module_name, replicas=self.replicas,
                 registry_hub=path_join(self.registry_hub, "middleware"),
@@ -304,4 +305,4 @@ class ServiceInterface:
                 etcd_endpoint=self.etcd_endpoint,
                 file_path=file_path)
 
-            self._exec_command_to_host(cmd=cmd, server=self.harbor_hosts[0])
+            self._exec_command_to_host(cmd=cmd, server=self.master_host)
